@@ -31,7 +31,7 @@ import subprocess
 import sys
 import zipfile
 
-__version__ = "0.29.0"
+__version__ = "0.30.0"
 
 is_windows = os.name == "nt"
 
@@ -249,8 +249,6 @@ def should_install_file(name, d):
 
 
 def transform_path(path, d):
-    if d["lib"] and d["pm"] and path.endswith("install-config.cmake"):
-        return f"{path}.in"
     if d["c"] and d["pm"] and path.endswith("_test.c"):
         return f"{path}pp"
     return path
